### Description
 
Preservation aims to keep valuable objects safe from harm. Experiment, by contrast, implies potential failure and the possibility that value is tentative and relational. In publishing, the tension between keeping things safe and experimental practices gains renewed urgency with the move from print preservation, concerned with safeguarding bounded objects, to the notoriously challenging task of maintaining complex digital publications. 
 
### Full description
 
Experimental books often challenge prevalent archiving and preservation practices because they rarely fit infrastructural categories designed to hold more or less standardised publications. Conventional books, consisting of static text and images, are submitted to repositories for digital preservation in a package containing the original manuscript files and the associated metadata file. Digital publishing experiments explode the notion of a self-contained book object because they frequently include distributed, versioned files, annotation, comments, backlinks, dynamic computation, non-linear interaction and third-party data (such as streaming videos or large databases) that do not fit into a neat package. Reflecting on this development [Greenberg, Hanson, and Verhoff (2021: 2)](https://doi.org/10.33682/0dvh-dvr2) note in their report on preserving new forms of scholarship that “publications may evolve in ways that present a serious challenge to preserving or even sustaining them in the long term.” Deborah Thorpe, Research Data Steward at the UCC Library, flags that preservation of online scholarship is an urgent concern because (important scholarly publications have vanished from the internet)[https://theriverside.ucc.ie/2023/11/02/preservation-online-publications/].
 
Besides the preservation of experimental publications, preservation also offers a rich field for experimentation. The politics, ethics, and practices of preservation are rife with tension. Among these tensions are the rarely problematised (digital) fantasy that everything can be preserved or the question of whose knowledge is or isn’t preserved that is central to feminist and decolonial archival work. In his essay on Experimental Preservation, [Jorge Otero-Pailos (2016)](https://doi.org/10.22269/160913) suggests that preservation is a way of testing objects’ (social) reality. His suggestion that preservation can be understood as a social litmus test for what is considered real and by whom, resembles Geoffrey Bowker and Susan Lee-Star’s observation that disrupting established infrastructures exposes the underlying political and practical considerations that are usually rendered invisible [(2000)](https://doi.org/10.7551/mitpress/6352.001.0001). In this sense, experimental publication that do not fit established preservation procedures can reveal assumptions about what constitutes good preservation, inviting authors, publishers and archivists to consider which realities, pasts and futures are preserved within publications and within the archives, catalogues, and libraries that hold them. 

### Experimental uses
 
Our colleagues at COPIM’s [Archiving and Digital Preservation Group](https://copim.pubpub.org/archiving-and-digital-preservation) note that “[t]he very nature of experimental publishing presents various challenges to the concept of digital preservation.” [(Barnes et al., 2023, p. 95)](https://doi.org/10.5281/ZENODO.7876048), because “authors and publishers are actively experimenting with possibilities […], which means there are no set standards or workflows.” For the purposes of preservation, Barnes differentiates between enhanced publications that augment a more or less classic book codex with additional media content and complex born-digital publications that cannot be replicated in print form because they rely on “multimodal content and the web’s interactive nature.” Many publishing experiments fall into the category of complex born-digital books, which creates issues for book preservation traditionally tasked with safekeeping distinct artefacts. Digital preservationists Greenberg, Hanson and Verhoff conclude that “[t]hese publications present formidable challenges for long-term preservation.” Their [Report on Enhancing Services to Preserve New Forms of Scholarship (2021)](https://doi.org/10.33682/0dvh-dvr2) sets out to “guide publishers to create digital publications that are more likely to be preservable.” The reports and blog posts of COPIM’s [Archiving and Digital Preservation Group](https://copim.pubpub.org/archiving-and-digital-preservation), and the [Digital Preservation Handbook](https://www.dpconline.org/handbook) provide further resources. Adding to these broader reports, the Experimental Publishing Group’s blog posts on preservation provide case studies of what the preservation of experimental [Computational Books], and (https://doi.org/10.21428/785a6451.2af49d16), [Combinatorial Books](https://copim.pubpub.org/pub/combinatorial-books-documentation-preservation-post8) entails in practice. 

#### Emulation

Digital books depend on software and hardware that are continuously becoming obsolete. Emulation can enable future readers to run the original publication in a virtual environment that simulates obsolete soft- and hardware. Acknowledging that it will not always be possible to preserve or emulate the original digital environment, Greenberg, Hanson, and Verhoff recommend providing (“visual and narrative documentation of the user experience ”)[https://doi.org/10.33682/0dvh-dvr2](2021), raising the question of what can and should be preserved. 

#### Third-party dependencies

Reliance on third-party resources outside the publisher’s control, such as large data sets, streaming and computation services, or links to external websites, is challenging for preservation. Service providers and databases eventually vanish, causing link rot when links stop working over time. So-called unique, persistent identifiers are more reliable than ordinary web links. Still, digital permanence remains a question of faith. Packaging or embedding external resources for preservation is one promising approach. On the downside, embedding resources implies potential copyright issues, can be labour-intensive, and becomes storage-intensive for resource-heavy, frequently versioned titles. Providing good enough snapshots, rather than full functionality, could, in many cases, be a more realistic goal. 

#### Assembly

Complex digital books consist of files that remain inaccessible to (human or machine) readers who do not know how to assemble them. Noting that emulation requires detailed knowledge of the original dependencies [Greenberg, Hanson, and Verhoff (2021)](https://doi.org/10.33682/0dvh-dvr2) recommend including a user manual in the form of a README file as is customary for software.

#### Versioning 

Most digital publications exist in multiple output formats and versions ([See also versioning](https://compendium.copim.ac.uk/practices/66)). Experimental publications like [Combinatorial Books](https://copim.pubpub.org/pub/combinatorial-books-documentation-preservation-post8), or [Living Books](https://compendium.copim.ac.uk/books?view=None&practice=&year=&typology=living), for example, include frequently updated and backlinked versions, while dynamically rendered publications such as [*Mutant Assembly*](http://mutantassembly.net), or [computational books](https://compendium.copim.ac.uk/books?view=None&practice=&year=&typology=computational) generate unique versions on execution. This raises the question of which version to preserve.

#### Whose objects, whose reality? 

Otero-Pailos (2016) points out that preservation tests whose realities are considered real and thus worthy of preservation. This question is central to feminist and decolonial scholars’ efforts to uncover gendered and racialised realities that have not been preserved or obfuscated in official records or, indeed, literary and scholarly canons. In this context, Christina Sharpe’s [*In the Wake: On Blackness and Being* (2016)](https://www.dukeupress.edu/in-the-wake) and [Julietta Singh’s *No Archive Will Restore You* (2018)](https://doi.org/10.21983/P3.0231.1.00) are but two outstanding examples of books that unearth realities hidden in full view. [*As I Remember It: Teachings (Ɂəms tɑɁɑw) from the Life of a Sliammon Elder* (2019)](https://compendium.copim.ac.uk/books/94) provides an example of an experimental publication dedicated to preserving indigenous knowledge in a colonial nation-state. 

#### Queering categories

Experimenting with the categories that are used to catalog books for preservation can expose the underlying politics and assumptions. Every publisher, for example, must assign a place of publication. punctum books are queering the territorial demand that books must originate in a place by publishing their books on Earth, Milky Way. Anonymous authorship or using specific control characters like $ are other ways of questioning cataloguers’ ability to categorise books for preservation.

### Considerations 

#### Planning

Decisions on what and how to preserve will influence the publishing process, platforms and output file formats. Given the complexity of preserving experimental publications, preservationists recommend bringing a [“preservation mindset into pre-preproduction”](https://doi.org/10.33682/0dvh-dvr2). Not considering preservation from the outset might make preservation costly and challenging. 

#### Responsibilities

Digital publications blur the boundary between research data and published versions, creating ambivalence about who is in charge of preserving what part of the process. For example, early annotated versions of an experimental text or supporting research data might be subject to research data management and, thus, the responsibility of the research team or become part of the publisher’s preservation workflow. Clarifying preservation responsibilities avoids misunderstandings that might lead to data loss. 

#### Automatic versus manual ingestion

Automatic preservation workflows save labour and cost. On the downside, automatic ingestion usually does not work (well) for experimental publications requiring manual compiling of preservable file packages, including meta-data files that clarify how to assemble the package into a readable publication. Given the cost of manually depositing preservation packages and meta-data, publication teams might have to consider what parts of the publication can be preserved long-term with the available means.

#### What to archive? 

The intertwined practical, technical, and conceptual challenges of preserving experimental digital publications long-term remind us that forgetting and deleting are essential functions of preservation. [Greenberg, Hanson, and Verhoff (2021)](https://doi.org/10.33682/0dvh-dvr2) recommend establishing “For each work […] what readers need in order to perceive the authors’ intellectual and rhetorical contributions, acknowledging that the current form of the publication may not be available in the future with changing technologies and social frameworks”. Acknowledging the impossibility of preserving all aspects of experimental digital publications challenges authors and publishers to question why and what to archive, rendering preservation an essentially experimental practice. 
 
### Further reading
 
Adema, J. (2023). Conversations on Archiving and Preserving Computational Books. Copim. [https://doi.org/10.21428/785a6451.2af49d16](https://doi.org/10.21428/785a6451.2af49d16)

Barnes, M., Bell, E., Cole, G., Fry, J., Gatti, R., & Stone, G. (2022). WP7 Scoping Report on Archiving and Preserving OA Monographs (1.0). Zenodo. [https://doi.org/10.5281/zenodo.6725309](https://doi.org/10.5281/zenodo.6725309)
 
Greenberg, Jonathan, Karen Hanson, and Deb Verhoff. ‘Report on Enhancing Services to Preserve New Forms of Scholarship’. 0 ed. New York, NY: New York University. [https://doi.org/10.33682/0dvh-dvr2](https://doi.org/10.33682/0dvh-dvr2)
 
Kiesewetter, R. (2023). Preserving Combinatorial Books. Copim. [https://copim.pubpub.org/pub/combinatorial-books-documentation-preservation-post8](https://copim.pubpub.org/pub/combinatorial-books-documentation-preservation-post8)