### Description

Translating is inherently experimental because it requires the approximation of meaning through trial and error. Translating experiments have the potential to make explicit what is lost and gained when moving languages, texts, words and debates from one situated context to another.

### Full description

There is a vast literature on the politics, aesthetics and ethics of translating. Joel Scott’s book *Translation and Experimental Writing* provides useful points of departure, informed by translation theory and empirical case studies. In line with the observation that translating is inherently experimental, Scott invites readers to reconsider translation as an experimental writing practice [(2018)](https://www.waterstones.com/book/translation-and-experimental-writing/joel-scott/9781138672956). Noting that translating is experimental at the core grants the question of what is at stake when the experimental character of translating is made explicit.

Michel Callon’s sociology of translation considers the capacity to conduct or resist translations between actors, practices and networks central to the configuration of power [(1986)](https://doi.org/10.1111/j.1467-954X.1984.tb00113.x). Callon’s broader understanding of translation as a way of bringing some voices, actors and realities into being points to issues around voice, visibility and appropriation that play out in all translations, but tend to be brought out more explicitly in translation experiments. The English literature scholar Lily Robert-Foley helpfully positions experimental translation in opposition to conventional notions of translation, which she notes, rest on the idea that it is possible to faithfully transcribe original works crafted by singular authors from one language to another [(2021)](https://doi.org/10.1093/english/efaa032). Robert-Foley, along others, points out that implied ideals of "fidelity, equivalence, accuracy, transparency, smoothness, and legibility" rest on notions of individualised authorship, personal property, and transcendent authority that obscure the experimental, tentative and collaborative character of translation alongside questions of power and access.

Drawing on feminist and postcolonial scholarship, Robert-Foley understands translating as an aesthetic, political and ethical practice because, like writing, translating is never done alone, and like writing, translating far from providing an unbiased transmission, shapes which worlds and voices are heard or made invisible [(2021, p. 411)](https://doi.org/10.1093/english/efaa032). Anthony Cordingley and Céline Frigau Manning ground the insight that translating is never done alone in a historical analysis of collaborative translation. By showing that translation has historically been a collective endeavour that has only relatively recently, and only in Western discourses, been ascribed to individual, heroic translators. The individualisation of heroic translations, they note, mirrors and reinforces the figure of the author. Cordingley and Manning’s argument that figuring translation as individual labour is a historical exception that reinforces gendered and postcolonial patterns of exclusion and silencing provides a fertile ground for experiments in translation as a collective, tentative achievement of human and machine collaborators [(2017)](https://doi.org/10.5040/9781350006034).

In the introduction to the special issue [(*Words to Think with*)](https://doi.org/10.1177/0038026120905452), the science and technology scholars Anne-Maire Mol and John Law consider the political, ethical and ontological effects of normalising English as the default of scholarly communication. Noting that in the social sciences, in 2005, three-quarters of all papers were published globally in English, they point out that English, despite its dominance, is not a lingua franca because, unlike with Medieval Latin, for example, there are English native speakers, and those who have to go the extra mile to speak and write in English, creating patterns of exclusion. Mol and Law flag that enforcing *one* version of proper global (scholarly) English is missing out on a wealth of analytical possibilities. Understanding that language cannot meaningfully be separated from places, practices and concerns, Mol and Law warn that the hegemony of academic English mutes debates, subjects and issues that do not translate into globalised English academic language, which in turn severely undermines the relevance of scholarly work in non-English dominated context. Translation, understood from the perspective of situated practice, is not the circulation of universal texts but the work of re-situating text, words and issues.

### Experimental uses

Situated understandings of translation that conceive of reading, writing, editing, reviewing, forking and publishing as acts of translation entangled in particular concerns and power relations invite us to attend to and play with what is lost and gained when moving between languages, texts, words and debates. Against the background of the dominance of academic English and continuous feminist and postcolonial critique of hegemonic discourses, scholarly writers explore the potential of working *inter-linguistically.*

For example, the authors Winnie Soon and Geoff Cox set out to translate their book *Aesthetic Programming: A Handbook of Software Studies* from English into Chinese. Following the book’s initial publication in English, the authors are *translating/forking* the book in collaboration with Taiwanese art and coding communities, exploring similarities between forking and translating. In the process, they are exploring how tools (such as DokuWiki, MediaWiki, PmWiki, WikkaWiki, HackMD, Git) could facilitate the process of linguistic and cultural translation [(Soon, 2022)](https://wg.criticalcodestudies.com/index.php?p=/discussion/132/week-4-translating-aesthetic-programming). 

The immersive online publication [*As I Remember It: Teachings (Ɂəms tɑɁɑw) from the Life of a Sliammon Elder*](https://compendium.copim.ac.uk/books/94) (2019) by Elsie Paul with Davis McKenzie, Paige Raibmon, and Harmony Johnson sets out to record indigenous teachings of the Tla’amin Nation. Most audio recordings that inform the final text are recorded in English (with some Sliammon phrases and terms). While the book involves translating between different languages, it also sets out to translate oral indigenous narratives and histories into a multi-media online publication. The publication can thus be understood as an experiment in translating between different knowledge regimes and forms of record. Because the authors are concerned that their translation project might force an external frame of interpretation on "Indigenous people living in a colonial nation-state," they are careful to "align with agendas set by Indigenous people for decolonization and healing." The authors use *transformational listening* to describe how translating between different knowledge regimes transforms not just the text but the translator's framework of interpretation. 

While translation experiments in scholarly work are getting more traction, they are certainly not as developed as the traditions of literary experimental translations. Hence, it’s worth turning towards the latter for inspiration. Robert-Foley provides something like a tentative typology of translation experiments inspired by notions of translation such as "creative translation (by Santiago Artozqui), poetic translation (by Tim Atkins), potential translation (by Pablo Martín Ruiz and Irène Gayraud), translucinación (by Vincent Broqua by way of Andrès Ajens by way of Jena Osman and Juliana Spahr), transcreation (Haroldo de Campos), transelation (Erin Mouré), perverse translation (Sherry Simon), and queer translation (Allison Grimaldi-Donahue and Amanda Murphy)."

> They can be translations that tamper with the very idea of what is considered a signifying unit or that divert from common conceptions of the intended meaning of a text.  
> They can translate one dimension of the text but not another, such as the sound or the shape.  
> They can vary in quantity, translating one word as many (beyond reason) or many words as one (beyond reason).  
> They can be translations that change mediums, registers, genres, text type, lexical field, or perhaps even create a new made-up language.  
> They can travel backwards or forwards in time.  
> They can translate between orality and writing.  
> They can be translations that use (in the wrong way) external tools such as the Internet, automatic translation generators, or employ filters, physical material, substances, or other devices (like a shower or a shot gun).  
> They can be cut-ups,  
> collages,  
> or pastiches,  
> combining translations or languages together.  
> They can appropriate, reappropriate, or disappropriate.  
> They can translate one language into many  
> or many languages into one.  
> They can be playful self-translations  
> or bilingual genesis.  
> They can translate texts that don’t exist.  
> They can be models of constraints, games, or text generators that can be applied time and time again,  
> or they can be singular transformations of a specific text.  
> They can use writing as a form of translation, translation as a form of reading, reading as a form of writing, writing as a form of reading, reading as a form of translation, or translation as a form of writing (or translation as a form of dance, music, game, cuisine, knitting, itinerary ... or the inverse, ad infinitum).  
> They use proliferation, multiplication, erasure, deviation, de ́tournement, distortion, recreation, rewriting, adaptation, localization, relocalization, commentary, interpolation, cannibalism, recombination, ekphrasis, calque, paraphrase, illegibility, lyric re-embodiment, and footnote  
> In some instances, but not all, the creative practice has been displaced from the text, the writing itself, to the development of the device that is used to transform the original.  
> [(Robert-Foley, 2021, p. 404)](https://doi.org/10.1093/english/efaa032)

### Considerations

Understanding translation as a power-differentiated practice, like the realisation that translation implies betrayal, raises ethical questions about how to engage *well* with *original* sources, *authors* and *communities* of practice. Open access and Creative Commons licences encourage reuse and rewriting, such as translation. In the absence of legal obligations to request permission, that tends to obscure questions of ethics, who might translate whom on what terms is subject to open negotiation and thus an explicit part of the politics of experimental translations.

### Further reading

Cordingley, Anthony, and Céline Frigau Manning. 2017. 'What Is Collaborative Translation?' In *Collaborative Translation: From the Renaissance to the Digital Age*, edited by Anthony Cordingley and Céline Frigau Manning. Bloomsbury Academic. <[https://doi.org/10.5040/9781350006034](https://doi.org/10.5040/9781350006034)>.

Colby, Georgina, ed. 2020. *Reading Experimental Writing*. Edinburgh, Scotland: Edinburgh University Press.

Law, John, and Annemarie Mol. 2020. 'Words to Think with: An Introduction'. *The Sociological Review* 68 (2): 263–82. <[https://doi.org/10.1177/0038026120905452](https://doi.org/10.1177/0038026120905452)>.

Robert-Foley, Lily. 2021. 'The Politics of Experimental Translation: Potentialities and Preoccupations'. *Journal of the English Association* 69 (267): 401–19. <[https://doi.org/10.1093/english/efaa032](https://doi.org/10.1093/english/efaa032)>.

Scott, Joel. 2018. *Translation and Experimental Writing* : Routledge