### Description

Copyright licensing determines the rights for the publication, distribution, and use of research  on a spectrum from completely closed fully copyrighted works, to open commons-based licenses. Yet within this spectrum various experiments have been taking place with copyright and licensing, both in how it is applied, conceptualised, and performed (for example in relation to experimental books) and how it is taken up by users and readers.

### Full description

In academic publishing, authors have tended to transfer the copyright for their research works to publishers for their works to subsequently be published all rights reserved with limited opportunities for reader reuse or interaction. The move to digital and OA publishing of books led to experiments with new forms of licensing, often also allowing authors to retain copyright. Within a legal context the terminology used most often is open licensing, which includes modifications, derivatives, fair use, or transformative use of texts, data, and resources. There are various reasons why open licensing might be beneficial for humanities research. For one it can lead to a wider uptake of research, for example through translations of works [(Vézina, 2020)](https://creativecommons.org/2020/04/21/academic-publications-under-no-derivatives-licenses-is-misguided/). Open licenses, therefore are a good way to enable interaction with book content and to create amenable conditions for engagement by signalling what kinds of reuse and interaction with a book are permitted without having to reach out to the publisher or rights owner to ask for permission to do so. Creative Commons (CC) licenses are one of thea ways to express different permission levels. Less restrictive licences tend to be most amenable to fostering reuse. Yet, as Martin Eve highlights, the argument for open licensing is different within the humanities than it is for example in computer science—less about freedom of information and code, and more about the fact that existing copyright provisions (e.g., fair use) are not adequate to accommodate existing humanities research practices [(Eve, 2014)](https://doi.org/10.1017/CBO9781316161012). Yet beyond current copyright legislation not covering existing (collaborative and digital) research practices, many researchers also experiment with reuse and remix as a critical practice exactly to challenge existing liberal humanist copyright regimes and established ways of doing and publishing research and the connotations of individual authorship, originality, and the ownership of research that comes with them. This includes critique of CC licenses, which as Gary Hall argues are “also extremely individualistic and liberal, providing a range of licenses for sovereign human authors to freely select from, as we say, rather than advocating for a collective agreement or philosophy” [(Hall, 2023)](https://copim.pubpub.org/pub/combinatorial-books-documentation-copyright-licences-post6).

### Experimental uses

As Hall has also outlined, other open licenses take a different approach, for example the Collective Conditions for Reuse (CC4r) license, developed by Constant, a Brussels-based non-profit organisation, “is endeavouring to move Free Culture in a direction where authorship and creativity are understood as being always-already collective, collaborative and situated, and as involving ‘human-machine collaborations and other-than-human contributions’ – rather than being ‘derived from individual genius’ as they are for conventional copyright“ [(Hall, 2023)](https://copim.pubpub.org/pub/combinatorial-books-documentation-copyright-licences-post6). Understood as a critique on conceptions of property and copyright of the neoliberal system, CC4r is a reimagined copyleft license specifically geared towards reuse or remix scenarios in which collaborators do not want to “contribute to oppressive arrangements of power, privilege and difference” [(Constant, 2023)](https://constantvzw.org/site/Collective-Conditions-for-Re-Use-CC4r,3483.html?lang=en?w=https://constantvzw.org/wefts/cc4r.en.html). It is based on the Free Art License and inspired by other licensing projects such as the (Cooperative) Non-Violent Public License and the Decolonial Media license [(Constant, 2023)](https://constantvzw.org/site/Collective-Conditions-for-Re-Use-CC4r,3483.html?lang=en?w=https://constantvzw.org/wefts/cc4r.en.html). CC4r is already used by Open Humanities Press to publish *Volumetric Regimes*, edited by Jara Rocha and Femke Snelting, published in its *DATA Browser* book series. CC4r is representative of alternative ways to license research works more critical of traditional conceptions of copyright, such as CopyLeft and CopyFarLeft licenses. Copyleft licenses have evolved out of Free, Libre and Open Software (FLOSS) advocacy and related licenses, such as the GPL, and the Copyleft project has a concise guide on the many aspects of copyleft licensing. The publisher Minor Compositions makes use of a tailored variant of a copy(far)left license for their books, including for Stevphen Shukaitis book *Combination Acts: Notes of Collective Practice in the Undercommons*. Copyfair licenses comprise a particular subclass that focuses on equitable sharing of resources. Most notably among those is the Peer Production License which has been conceived in the context of the Open Cooperativism movement as a derivative of the Attribution-NonCommercial-ShareAlike Creative Commons license. The Institute of Network Cultures’ book series *Network Notebooks* has been published under a Peer Production License, see for example Dmytri Kleiner's *The Telekommunist Manifesto*. Other approaches to copyleft licensing that focus on fair distribution of value include the CopyFair License and the Fair Source License. Copyleft licenses that are usually found in software development such as MIT & GPL3 have also been applied to OA books, see the Berlin-based *Mute Magazine*’s Open Mute Press collaboration with Open Humanities Press on *After.Video*, a video book consisting of a paperback book and video stored on a Raspberry Pi computer packaged in a VHS case. 

### Considerations

Related to the above, a complication with open licensing is in cases where it concerns the reuse of indigenous or community knowledge, for example in anthropological settings, where “questions of ownership, control, access, and possession (OCAP) of intellectual property and cultural materials are key considerations for Indigenous communities, who since the time of contact with settler populations have seen their cultural content stolen, misappropriated, and misrepresented” [(Cullen and Bell, 2018)](https://doi.org/10.3138/jsp.49.2.193). In addition to this, traditional and indigenous knowledge often has its own cultural and access protocols, determining if and how that knowledge can be (re)used and circulated, by whom, and under which conditions, which also further complicates common open-closed binaries [(Christen, 2012)](https://ijoc.org/index.php/ijoc/article/view/1618). As Bell and Cullen point out, the publishing process, with its focus on copyright, single authorship, and the bound book (which implies knowledge is not always easily available for further remix by the community) often doesn’t accommodate collaboration with diverse knowledge communities. What is important in this context, as Okune et al. have outlined, is that clear research contracts with indigenous communities are set-up and co-designed with the communities “to define when, where and how their community knowledge is used by external researchers” [(Okune, Hillyer, Chan, Albornoz, & Posada, 2019)](http://books.openedition.org/oep/9072).

Inspired by CC, Traditional Knowledge (TK) Labels seek to address the diversity of Indigenous needs to retain control of their cultural heritage and resources. TK “embraces the content of knowledge itself as well as traditional cultural expressions, including distinctive signs and symbols associated with TK” and are “a tool for Indigenous communities to add existing local protocols for access and use to recorded cultural heritage that is digitally circulating outside community contexts. The TK Labels help non-community users of this cultural heritage understand its importance and significance to the communities from where it derives and continues to have meaning” [(Program for Open Scholarship and Education, 2021)](https://pose.open.ubc.ca/open-access/author-rights/traditional-knowledge/). The University of British Columbia provides further details on the uses of TK Labels and Cullen and Bell explain how the books they are publishing at UBC Press, which draw upon indigenous resources or databases, can, through the use of TK Labels, be accessed, shared, and repurposed while respecting cultural protocols and different understandings of OCAP of intellectual property and cultural materials. For them, even though the books and the collections they draw upon remain separate, it proved essential to link the books back to the project or materials they were researching, to ensure the books themselves again become part of the indigenous commons: “It was critical to the research teams, however, that the books remain a part of the project’s full suite of outcomes and resources” [(Cullen and Bell, 2018)](https://doi.org/10.3138/jsp.49.2.193). The open access publication *As I Remember It*, a collaboration between Elder Elsie Page, Davis McKenzie, Paige Raibmon, and Harmony Johnson published by RavenSpace, makes use of TK Labels.

One of the main critiques put forward by humanities scholars towards reuse and remix practices and open licensing is that they interfere with the academic integrity of their works, especially in cases where these practices concern perceived misuse of research (e.g., libel, plagiarism, false attribution, piracy). Yet as Vézina argues, copyright and open licensing in general are not the best frameworks to address issues of misuse of research, as this is mainly addressed through institutional and social norms and moral codes of conduct around plagiarism and misappropriation [(Vézina, 2020)](https://creativecommons.org/2020/04/21/academic-publications-under-no-derivatives-licenses-is-misguided/). Neither traditional copyright, nor open licensing protect against research misuse. Yet others go even further in their critique. The historian Peter Mandler outlines how any remixing or reusing of humanities texts is problematic where he stands by the unique originality of our words as researchers. Many similar objections to reuse arise in the literature around CC licenses, particularly CC BY, that provide blanket permission to reuse scholarship (if attribution is provided). Mandler fears as he states the ‘booby-traps’ that are embedded with the CC BY licence, particularly the ability to remix content in ways of which the original author does not approve [(Mandler, 2014)](https://doi.org/10.1629/2048-7754.89). Such scepticism of CC BY is common within the humanities, particularly in response to policy consultations that mandate CC BY as the default licence for OA ([Kingsley, 2016]([https://unlockingresearch-blog.lib.cam.ac.uk/?p=555), [The British Academy, 2018](https://www.thebritishacademy.ac.uk/documents/83/British_Academy_paper_on_Open_access_and_monographs-May_2018.pdf), [Arts and Humanities Alliance, 2019](http://artsandhums.org/news-2/plan-s-consultation-response/)). The reuse of resources included in books also remains an issue in relation to third-party rights, for example in the case of images, and/or musical, or choreographical scores included within books. In many arts and humanities disciplines the rights to research materials are owned by others who need to provide permission for their reproduction. This has made it more difficult to attach open licenses to books as a whole.

A further complication might be that the libre OA strategy (making a work available online free of price and permission barriers) has in most settings combined commercial reuse with the right to derivatives and modifications (i.e. a focus on the CC BY license), where for example in the context of much publishing in Latin-America where, different national and regional contexts notwithstanding, the focus is predominantly on non-commercial scholarship and publishing—there is a distrust of CC BY’s focus on commercial reuse [(Lujano, 2017)](https://blog.doaj.org/2017/01/17/challenges-of-the-latin-american-open-access-publishing-model/). Hall interrogates the scepticism with CC BY from an alternative perspective stating that it affords too much control to the original author by requiring attribution and thus associating the work as property of the author. This works against reuse by preventing the creation of a ‘common stock’ of digital materials to be used and reused by whomever wants to do so. Instead, CC BY presumes that the digital material is the author’s ‘property’ and so offers merely a reformist take on intellectual property instead of a fundamental critique of it [(Hall, 2016: 5)](https://mitpress.mit.edu/9780262034401/pirate-philosophy/). For Hall, then, the kinds of reuse and remix encouraged (but not completely supported) by CC BY would thus depend on the dismantling of the “unified, sovereign, proprietorial subject” [(Hall, 2016: 9)](https://mitpress.mit.edu/9780262034401/pirate-philosophy/).  

### Further reading

Constant (2023). Collective Conditions for Re-Use (CC4r). 
[https://constantvzw.org/site/Collective-Conditions-for-Re-Use-CC4r,3483.html?lang=en?w=https://constantvzw.org/wefts/cc4r.en.html](https://constantvzw.org/site/Collective-Conditions-for-Re-Use-CC4r,3483.html?lang=en?w=https://constantvzw.org/wefts/cc4r.en.html)

Program for Open Scholarship and Education. (2021). Traditional Knowledge. In *Program for Open Scholarship and Education*. [https://pose.open.ubc.ca/open-access/author-rights/traditional-knowledge/](https://pose.open.ubc.ca/open-access/author-rights/traditional-knowledge/)

Copyleft and the GNU General Public License: A Comprehensive Tutorial and Guide: [https://copyleft.org/guide/](https://copyleft.org/guide/)