### Description

Referencing, citing, crediting, and acknowledging are crucial practices to make connections to previous research, to support argumentation, and to further advance the scholarly conversation while crediting those who our scholarship builds upon. At the same time references and citations play a significant role in the academic value and merit system and their growing importance reflects the ongoing metrification of scholarship.

### Full description

Citation and referencing practices differ per field and research context yet citing sources is a well-established and highly codified academic practice that can help readers to fact check evidence and identify further reading. It also serves to authorise arguments, validate positions, naturalise statements as fact, and build economies of visibility that tend to amplify the reach and resources of already established cliques and writers while rendering the labour of others invisible. The politics of citation, as an essential aspect of how value (and with that impact, relevance, esteem, and credibility) is determined within academic communities, has led to forms of structural marginalisation and silencing of certain groups, with consequences for hiring, career progression, and the evaluation of performance. Failure to cite already marginalised groups has created further inequity within scholarship and has resulted in the exclusion of certain voices from the scholarly conversation alongside the often uncritical reproduction and of mostly white, male, heteronormative thought from the Global North [(Mott and Cockayne, 2017)](https://doi.org/10.1080/0966369X.2017.1339022). As a result, disciplines and fields tend to reproduce themselves in exclusionary ways [(12 Women Scholars, 2021)](https://www.insidehighered.com/advice/2021/08/27/entrenched-inequity-not-appropriately-citing-scholarship-women-and-people-color). 

For many scholars therefore, citational practices have become a potential site of resistance to create more equitable knowledge practices and infrastructures within academia [(Itchuaqiyaq and Frith, 2022)](https://doi.org/10.1145/3507870.3507872). As Max Liboiron writes in reference to citations as 'screening techniques', "citing the knowledges of Black, Indigenous, poc, women, lgbtqai+, two-spirit, and young thinkers is one small part of an anticolonial methodology that refuses to reproduce the myth that knowledge, and particularly science, is the domain of pale, male, and stale gatekeepers" [(Liboiron, 2021, viii)](https://www.dukeupress.edu/pollution-is-colonialism). Yet at the same time it has been argued that a focus on more inclusivity should not come at the expense of a rethinking and reperforming of how our citational practices are currently and have historically been set up and normalised, especially also in relation to citation counting, the ongoing metrification of scholarship, and the reproduction of established hierarchies in knowledge production (Calderón, 2022; [Mott and Cockayne, 2017](https://doi.org/10.1080/0966369X.2017.1339022); [McKittrick, 2021](https://www.dukeupress.edu/dear-science-and-other-stories)). 

### Experimental uses

More experimental uses of referencing in academic books have therefore focused on highlighting the relationalities and engagements that referencing creates, as well as the community-forming potential that alternative forms of referencing can afford (Maddrell, 2015; [Mott and Cockayne, 2017](https://doi.org/10.1080/0966369X.2017.1339022)). Some examples of more equitable forms of citation and referencing include the citation policy Sara Ahmed describes in her book *Living a Feminist Life*: "Citation is how we acknowledge our debt to those who came before; those who helped us find our way when the way was obscured because we deviated from the paths we were told to follow. In this book, I cite feminists of color who have contributed to the project of naming and dismantling the institutions of patriarchal whiteness" [(Ahmed, 2017, 15-16)](https://www.dukeupress.edu/living-a-feminist-life) and D’Ignazio and Klein’s (updatable) addendums (which include both a self-audit and an external audit) to their book *Data Feminism*, in which they reflect on their own aims and values in relation to citational practices and metrics, including their aim to "listen and give priority in the text to voices who speak from marginalized perspectives, whether because of their gender, ability, race, class, colonial status, or other aspects of their identity" [(D’Ignazio and Klein, 2020)](https://data-feminism.mitpress.mit.edu/). Katherine McKittrick in *Dear Science and Other Stories* (itself a book that experiments with foregrounding footnotes and references in an ongoing conversation with the main text) highlights how the practice of citation is a practice of sharing how we know. As she states, "I am not interested in citations as quotable value. I want to reference other possibilities such as, citations as learning, as counsel, as sharing" [(McKittrick, 2021, 26)](https://www.dukeupress.edu/dear-science-and-other-stories). As McKittrick argues, the work of citation, specifically also for black feminists, is not about claiming something known as something that is owned, but it is about sharing how to live, sharing ideas about how to struggle against oppression and how to do the work of liberation. Further guides to more equitable citation practices and to start to cite in a more conscious and thoughtful way include projects such as Cite Black Women and the FEM (Female Empowerment Maastricht University network) citation guide. 

Practices of referencing also play a crucial role in Digital Humanities and other experimental research and publishing projects in which the acknowledgement of often large groups of contributors can become complicated, including how to credit the efforts of people such as designers, developers, project managers, community members, reviewers, editors, etc. Efforts to make these different contributions and roles more visible include the Collaborator’s Bill of Rights and CRediT (Contributor Roles Taxonomy), a high-level taxonomy, including 14 roles, that can be used to represent the roles typically played by contributors to research outputs. Experimental publishing platforms such as PubPub already allow multiple roles to be identified on a Pub and publisher Mattering Press acknowledges the various contributors involved in making their books (including designers, developers, advisers, reviewers etc.) in their books’ colophon as  per default. Alternatives have also been developed in relation to the order in which authors are named on a publication. Customs around this differ widely between disciplines, from acknowledging authors in alphabetical order to naming the lead author(s) first or last. Conscious efforts adopted by authors to highlight the equal nature of their co-authorship include publishing under joint (pen) names, see for example the joint name J.K. Gibson-Graham used by economic geographers Julie Graham and Katherine Gibson and the joint name EJ Ringold used by the sociologists EJ Renold and Jessica Ringrose, while food geographer Ian Cook "writes as 'Ian Cook et al' because he/they/we never work alone". Other scholars have published under a collective name or under the name of research groups or laboratories. The feminist marine science laboratory CLEAR (Civic Laboratory for Environmental Action Research) outlines how "rather than a metric system that remains stable across articles and contexts, CLEAR uses a situated and context dependent process that assumes decisions about author order will be different for every paper" [(Liboiron et al., 2017)](https://doi.org/10.28968/cftt.v3i2.28850). Their protocols, based on a situated process that recognizes diversity and difference in rewarding the different contributions to knowledge production, can never be systematized they state, and foregrounds equity, and a shared commitment to consensus, care work, and acknowledgement of social location when awarding author order. 

Further experimental work in the (digital) humanities looks at the semantic uses of digital texts and how we now have an opportunity to establish closer connections between texts and data through open and machine readable or parsable citations. Citing scholarly works is one of the fundamental re-use practices established in academic culture and making citation data available in an open and machine-readable way is yet another way to invite re-use of one’s work. Here one of the main aims is to directly connect human and machine readers to the full text of a publication’s cited sources. In digital publications, citations are increasingly implemented as hyperlinks that lead directly to the source texts, or even link directly to specific sections of specific texts. For example, [Babini and Rovelli’s *Tendencias recientes en las políticas científicas de ciencia abierta y acceso abierto en Iberoamérica* (2020)](https://www.clacso.org/en/tendencias-recientes-en-las-politicas-cientificas-de-ciencia-abierta-y-acceso-abierto-en-iberoamerica/) is the first book in CLACSO´s interoperable (OAI-PMH) digital repository with interactive links in footnotes, and interactive links to open access references in the bibliography. The digitisation of publications has brought entire disciplines and research methodologies into being that track how works are interlinked by citation. The open nature of much of this data provides opportunities for experimental works that could either integrate such live data publications or create computational works that are generated through this data. 

Creating stable URLs and clear practices around data and tool citation is seen as crucial in this context. Leveraging the principles of open data through PIDs and Semantic Web (Linked Open Data) technologies, OpenCitations seeks to collect citation data to create semantic, machine-readable networks that link citations and references across individual research outputs. Implementing OpenCitation standards in one’s monograph creation workflow can be another way to improve and invite re-use of original content, as machine-readable, standardised metadata promises to make proper attribution of sources more readily available. As the provision of open reference lists plays an important part in the Declaration on Research Assessment (DORA), this practice will surely see even wider-spread uptake across HE institutions and publishers against the backdrop of the larger move towards facilitating uptake of practices on the spectrum of open sciences and scholarship. For a very recent discussion of the benefits and obstacles regarding OpenCitations, see e.g. [Ayers & Klein, 2021](https://doi.org/10.21428/6ffd8432.5af8c64c).

### Considerations

While the practice of using open references and citations in one’s output is seeing considerable uptake particularly in the STEM fields (see e.g. [Hutchins, 2021](https://doi.org/10.1162/qss_c_00138)), an adaptation of workflows that make reference and citation datasets openly available is still lagging behind in the Humanities and Social Sciences. Similarly, academic referencing and metadata systems and infrastructures are often closed and not interoperable and tend to have been set up in a highly formalised, standardised, and normative ways that do not easily invite experimentation with different forms of referencing as part of our publishing practices. Similarly print books and their digital equivalents in PDF format still heavily rely on print-based systems to add references and notes as part of standardised publishing workflows.

### Further readings

Ayers, P. and Klein, S. (2021). The Invisible Citation Commons. *Commonplace*, 1(1). [https://doi.org/10.21428/6ffd8432.5af8c64c](https://doi.org/10.21428/6ffd8432.5af8c64c). 

McKittrick, K. (2021). *Dear Science and Other Stories*. Duke University Press.

Mott, C. and Cockayne, D. (2017). Citation matters: mobilizing the politics of citation toward a practice of 'conscientious engagement'. *Gender, Place & Culture*. 24:7, 954-973. [https://doi.org/10.1080/0966369X.2017.1339022](https://doi.org/10.1080/0966369X.2017.1339022).

Okune, A. (2019, May 21). *Self-Review of Citational Practice*. Research Data Share, Platform for Experimental Collaborative Ethnography. [https://www.researchdatashare.org/content/okune-angela-2019-may-21-self-review-citational-practice-zenodo](https://www.researchdatashare.org/content/okune-angela-2019-may-21-self-review-citational-practice-zenodo).