### Description

Remix includes creating derivatives of 'original' works through reuse, adaptation, transformation, and modification. Remix practices in academia—from combining different media in innovative ways to collaboratively (re)mixing fragments of texts in new contexts—can complicate the idea of the proprietorial author creating original works while simultaneously exploring the interconnected relationship of scholarly texts. Much of this is predicated on openly licensed research objects that enable reuse of scholarly publications.

### Full description

Remix in academia is practised in various ways and known under different terms and concepts, from adaptation and appropriation in an art and literature context to open licensing in a legal context—capturing modifications, derivatives, fair use, and transformative uses of texts, data, and resources. Scholars tend to be familiar with remix in connection to Creative Commons licenses that allow (commercial) reuse or derivatives within academic publishing. In the context of open access publishing, reuse falls under the distinction between gratis and libre openness, capturing a positive connotation (describing kinds of access rather than kinds of access barriers) in relation to the removal of price and permission barriers. But the focus on reuse rights ultimately derives from computer science and the open software movement, where the gratis/libre distinction concerns software or code.

Remix and reuse lie at the basis of the research and writing process as scholars build upon and extend the writing, works, and arguments of others when they cite, reference, critique, analyse and reuse existing sources. In this sense 'derived use' is fundamental to how scholarship progresses. Reuse and remix practices are already embedded in our publishing systems, from reworking arguments and citations into new works, to (re)drafting scholarship from notebooks and index cards, to republishing previously published work in new editions. Publications incorporate feedback from the agencies involved in their production (scholars, typesetters, designers) where "in its complex weaving and invocation of other works, the scholarly book is not only a fertile repository of ideas, knowledge, and research; it is also inherently social" [(Cullen and Bell, 2018)](https://doi.org/10.3138/jsp.49.2.193). Beyond the fairly common remix practices of republishing, translating, adapting books to new media (e.g. audiobooks), and incorporating different media (e.g. texts, images, or videos), remix practices also include digital humanities derived methods of text and data mining and reuse (to create visualisations or media libraries or to adapt graphs or diagrams). More experimental remix practices include those in which texts, images, or videos are mashed up (e.g. vidding) or are re-interpreted as a form of critical engagement with the source texts or to explore and promote more equitable and collaborative forms of knowledge production.

The benefits of academic reuse range from wider uptake of research to increased accessibility. Due to technological advancements, data mining and technologies such as visualisation and re-use of large electronic text collections are now within reach of most humanities scholars. Importantly, with open licensing reuse is possible without needing to request permission from the publisher or right owner, which can put researchers off from legitimate forms of reuse. Similarly, with legislation differing worldwide, clear open licensing (see Creative Commons) supports further uptake of academic remix practices. Current copyright legislation doesn’t always cover collaborative and digital research practices, hence why many researchers experiment with remix as a critical practice to challenge existing liberal humanist copyright regimes and established ways of doing and publishing research and the connotations of individual authorship, originality, and the ownership of research that comes with them.

### Experimental uses

One often-cited example of reuse and remix is the *[Living Books About Life](http://www.openhumanitiespress.org/books/series/liquid-books/)* book series published by Open Humanities Press (OHP). This series 'repackaged' previously published open access content into curated edited collections. The books in this series are 'living' in the sense that they are "open to ongoing collaborative processes of writing, editing, updating, remixing and commenting by readers". This series shows the ability of reuse to deconstruct some of our preconceptions of what a book actually is, where the project displays a "continued theoretical reflection on issues of fixity, authorship and authority, both by its editors and by its contributors in various spaces connected to the project" [(Adema, 2021)](https://livingbooks.mitpress.mit.edu/pub/dp81vgde/). Inspired by this the [*Combinatorial Books: Gathering Flowers*](https://copim.pubpub.org/pub/combinatorial-books-gathering-flowers-part-i/release/1?readingCollection=1bb570ed) book series encourages the rewriting of books within OHP’s catalogue as a means of generating radical new responses to them. It is based on a publishing workflow that enables the creation of new combinatorial books out of existing open access books (or collections of books) available for reuse. For its [first iteration](https://copim.pubpub.org/pub/combinatorial-books-gathering-flowers-part-iii/release/1?readingCollection=1bb570ed), a group of Mexican scholars and technologists has rewritten *The Chernobyl Herbarium* by Marder and Tondeur "through disappropriation as much as appropriation", where the authors envisioned re-writing (following Rivera Garza) as "exposing the incomplete, processual nature of any text". Another publisher who has experimented with reusing their collection is Open Book Publishers, who run [OBP Customise](https://www.openbookpublishers.com/obp-customise), allowing one to mix, match, and personalise a publication. Chapters or whole books can be selected from OBP’s published list to make a special edition, a new anthology, or a coursepack (produced as paperback and downloadable PDF). Third-party content can also be included to create a new, composite book, complete with cover and introduction. Remix from text into different media is visible in Mark Amerika’s *remixthebook* (University of Minnesota Press), which is accompanied by the [*remixthebook.com*](https://www.remixthebook.com/) website with digital remixes of the theories generated in the print book. It features the work of 25 artists, creative writers, and scholars for whom the practice and theory of remix is central to their research interests. They sampled from *remixthebook* and manipulated the selected source material through their own artistic and theoretical filters.

### Considerations

The adoption of remix practices within the humanities can be frustrated by researcher inhibitions perpetuated by institutional structures. This includes the fear that remix interferes with the academic integrity of works, especially where these practices concern perceived misuse of research (e.g. libel, plagiarism, false attribution, piracy). Yet copyright is not the best framework to address issues of research misuse, which is mainly addressed through institutional and social norms and codes. Neither copyright, nor open licensing can protect against this [(Vézina, 2020)](https://creativecommons.org/2020/04/21/academic-publications-under-no-derivatives-licenses-is-misguided/). Many objections to reuse relate to the CC BY license, which provides blanket permission to reuse scholarship (with attribution). In practice though, many humanities scholars find remix of their books problematic as it interferes with their propriety and sense of ownership. This isn’t surprising given how authorship functions within academia, where single authored, original publications are preferred, and remix, reuse, and collaborative forms of research (e.g. creating databases) aren’t readily acknowledged as research. 

Another complication concerns the reuse of indigenous or community knowledge, where "questions of ownership, control, access, and possession (OCAP) of intellectual property and cultural materials are key considerations for Indigenous communities, who since the time of contact with settler populations have seen their cultural content stolen, misappropriated, and misrepresented" [(Cullen and Bell, 2018)](https://doi.org/10.3138/jsp.49.2.193). Traditional and indigenous knowledge often has its own cultural and access protocols, determining if and how that knowledge can be (re)used and circulated, by whom, and under which conditions, which also further complicates common open-closed binaries [(Christen, 2012)](https://ijoc.org/index.php/ijoc/article/view/1618). At UBC Press, books which draw upon indigenous resources or databases, can, through open licensing (they use [Traditional Knowledge Licenses](https://localcontexts.org/licenses/traditional-knowledge-licenses/)) be accessed, shared, and repurposed while respecting cultural protocols and different understandings of OCAP. The reuse of resources in books also remains an issue in relation to third-party rights in the case of images, and/or musical, or choreographical scores within books. This has made it more difficult to attach open licenses to books as a whole. Other inhibitions towards reuse include technical considerations around software design and implementation. As reuse tends to occur after a work has been published, workflows for iterative publishing need to adopt a more holistic approach that recognises different starting points within a publishing process (where the 'end point' of one publication may be the beginning of another [(Kasprzak and Smyre, 2017)](https://doi.org/10.3138/jsp.48.2.90)). 

### Further reading

Adema, J. (2021). *Living Books: Experiments in the Posthumanities*. Cambridge, MA, USA: MIT Press.

Amerika, M. (2011). *Remixthebook*. U of Minnesota Press. [http://www.remixthebook.com/](http://www.remixthebook.com/)

Navas, E. (2023) *Remix Theory: The Aesthetics of Sampling*. Springer.