### Description

Rewriting involves the practice of re-envisioning an already existing text without (necessarily) intervening into the original source text. It engages with the production of text and language and the way individuals and communities are created (and create themselves) through text and language. As an experimental practice, rewriting can act critically as a way to intervene into dominant paradigms in scholarly knowledge production (for example, singular and possessive authorship, the stability and authority of written text) and to perform them differently.

### Full description

Depending on the type of open licence, open access publications allow for practices such as the reuse, remix, and rewriting of already published texts and books as long as the source text is acknowledged. 

Conceptually, rewriting is closely related with practices of critical reading (or re-reading), annotation, and editing. Every text – no matter its claim for authority, fixity, and representativeness – is a cultural and social phenomena that does not exist as a singular object but as an event that through each reading is created anew ([Drucker, 2009](https://doi.org/10.1080/13534640903208834), [2014](https://doi.org/10.14195/2182-8830_2-1_1); [McGann, 1991](https://press.princeton.edu/books/paperback/9780691015187/the-textual-condition)). Hence, the reader is also a (co-)producer of texts. Through reading, one intervenes into the production of text and language and into the way individuals and communities are created (and create themselves) through text and language (Barthes, 1970; [Drucker, 2009](https://doi.org/10.1080/13534640903208834), [2014](https://doi.org/10.14195/2182-8830_2-1_1); [Rivera Garza, 2013](https://www.consonni.org/es/publicacion/los-muertos-ind%C3%B3ciles-necroescritura-y-desapropiaci%C3%B3n), [2020](https://www.vanderbiltuniversitypress.com/9780826501219/the-restless-dead/)). This co-production and intervention through reading, as Barthes (1970) and [Rebei (2004)](https://doi.org/10.4000/lisa.2895) note, can be linked to the practice of writing or rewriting existing texts. Digital technologies, platforms, and tools contribute to blurring the boundaries between reading, editing, annotating, and rewriting practices. For example, texts published on wiki platforms can be recomposed, rewriten, edited, annotated, translated and remixed by authors; and the annotation software hypothes.is as well as the annotation functions supported by publishing platforms such as PubPub and Manifold, allow individual readers or groups of readers to more directly interact with the published text. 

Rewriting has a long tradition in academia and literary production. With reference to its performative and interventionist aspect, rewriting – especially in feminist, queer, and decolonial individual and collaborative practice – has been used to expose established power structures inherent in narrative creation and representation and to perform these differently focusing on marginalised voices, their historical erasure, as well as the complex interrelation between text, memory, identity, and body. Adrienne Rich considers rewriting as a form of re-visioning. For her, rewriting, "the act of looking back, of seeing with fresh eyes, of entering an old text from a new critical direction—is for women more than a chapter in cultural history: it is an act of survival" ([1972:18](https://doi.org/10.2307/375215)). In [*Borderlands / La Frontera* (1987)](https://www.auntlute.com/borderlands-la-frontera-ce) Gloria Anzaldúa explores writing as a subjectivation practice, as a way of enabling new modes of being and becoming through writing (or storytelling) that have been suppressed in the way indigenous, queer, and female life, as well as the life of people-of-colour has been objectified within dominant modes of writing. Sylvia Wynter emphasises the relationship between interventionalist uses of writing and notions of embodiment through this writing. For her, rewriting – "[w]ords made flesh, muscle and bone animated by hope and desire" [(1995:35)](https://www.jstor.org/stable/j.cttq93rp.5) – is an existential task, as the category of the human itself has been under duress within western and patriarchal knowledge systems and with that conceptions of what it means to be human. Wynter’s proposition for (re)writing thus is "the possibility of undoing and unsettling […] Western conceptions of what it means to be human" [(McKittrick, 2015)](https://www.dukeupress.edu/sylvia-wynter). She emphasises that departing from these conceptions would require a collective engagement with the "rewriting of knowledge as we know it […] without falling into the traps laid down by our present system of knowledge" [(McKittrick, 2015: 2)](https://www.dukeupress.edu/sylvia-wynter). Cristina Rivera Garza ([2013](https://www.consonni.org/es/publicacion/los-muertos-ind%C3%B3ciles-necroescritura-y-desapropiaci%C3%B3n), [2020](https://www.vanderbiltuniversitypress.com/9780826501219/the-restless-dead/)) emphasises the importance of collaboration in her concept of rewriting as *disappropriation* geared at disengagement from all-encompassing global capitalism. In this concept, she suggests to restore the plural, collaborative roots of writing which, according to her, is often overshadowed by myths such as the individual and possessive author that large parts of academia and the book industry depend upon. Scholars such as [Denise Ferreira de Silva (2014)](https://doi.org/10.1080/00064246.2014.11413690) and [Joan Retallack (2004)](https://www.ucpress.edu/book/9780520218413/the-poethical-wager) have emphasised the importance of not positioning rewriting in a pre-decided oppositional politics, concerning its ethics and morals. Instead, they have suggested that rewriting can take the function of "a poetics of conscious risk, of letting go of control, of placing our inherited conceptions of ethics and politics at risk, and of questioning them, experimenting with them" [(Adema 2018, 21)](http://dx.doi.org/10.17613/M6DN3ZV67).

### Experimental uses

Experiments with rewriting of books have amongst others focused on making books openly editable for readers in an attempt to highlight the inherently collaborative nature of all textual production, to extend the range of collaborators on a book project; and to break down simple distinctions between the practices of authoring, editing, and reading. In this vein, all books in the Open Humanities Press (OHP) [*Living Books about Life*](https://www.livingbooksaboutlife.org/) series have been published online on an open source wiki platform, meaning they are themselves 'living' or open on a read/write basis for users to help compose, edit, annotate, rewrite, and remix the books of this series. 
Similarly, [*The Rewrite Collaborative Framework*](https://criticalmedialab.ch/projects/the-rewrite/) – a digital learning framework built around annotation as a collective practice – has aimed to support collaborative reading, writing and meaning-negotiation practices as enabling dialogue and action on urgent global challenges. Through workshops, teaching formats, and open courseware documentation, the digital learning framework aims to reach beyond the classroom, to build a growing community of learners, readers and publics interested in tackling environmental, social, and political issues. Among the resources and publications emerging from The Rewrite Collaborative Framework are [The Rewrite Collaborative Framework Browser Extension](https://irf.fhnw.ch/entities/publication/14503ab8-7df0-43fa-bff9-1c03c83b6cb6) that is based on the open source collaborative web-annotation software hypothes.is and the publication *Rewriting as Practice* ([Bruder, Sobecka, & Halpern, 2022](https://www.anthropocene-curriculum.org/courses/communicating/rewriting-as-practice)).

Another example of experimenting with collaborative rewriting is the bilingual (Spanish and English) publication [*Ecological Rewriting: Situated Engagements with The Chernobyl Herbarium*](https://ecologicalrewritings.pubpub.org/), the first book in the Combinatorial Books: Gathering Flowers series published by Open Humanities Press (OHP). Supported by the COPIM project, it is the creation of a collective of researchers, students and technologists from the Universidad Iberoamericana in Mexico City. Led by Gabriela Méndez Cota, this group of nine (re)writers first annotated an open access online version of *The Chernobyl Herbarium: Fragments of an Exploded Consciousness* by the philosopher Michael Marder and the artist Anaïs Tondeur provided on OHP’s website using the collaborative web-annotation software hypothes.is. In a shared writing pad (on HedgeDoc) they then ordered and categorised their annotations using tags and started to write out their annotations into a larger response to produce what is a new book in its own right – albeit one that comments upon and engages with the original. As [Méndez Cota et al (2023)](https://doi.org/10.21428/9ca7392d.07cdfb82) remark in the book: "rather than being pre-planned as a critical programme, our articulation of a situated reuse and rewriting of *The Chernobyl Herbarium* materialized gradually through the collaborative process of becoming experimental writers or 'rewriters'. At the same time, while we may have decided not to apply any pre-given method or strategy of artistic disruption or critical appropriation to a work we had chosen because it invited us to attune affectively with the fundamental fragility of existence, we nevertheless tried to reuse and rewrite it in a way that conveyed our respect and appreciation for the work of the others involved."

### Considerations

Rewriting activities bear the danger of reproducing dominant knowledge systems and related discourses and practices they aim to challenge. For example, [Liedeke Plate (2008)](https://doi.org/10.1086/521054) and Cristina Rivera Garza ([2013](https://www.consonni.org/es/publicacion/los-muertos-ind%C3%B3ciles-necroescritura-y-desapropiaci%C3%B3n), [2020](https://www.vanderbiltuniversitypress.com/9780826501219/the-restless-dead/)) remark that, under the dominant market-driven and individualising logics of both contemporary academia and the literary scene, the critical re-writer risks to reperform the traditional Western, humanist idea of the an individual and authoritative author-genius competing, through rewriting, for reputational and financial reward. Additionally, counter-discursive practices – such as the rewriting of already existing texts –run the risk of situating the re-written text in an oppositional relation to an 'original' one. This is problematic in so far that, as [Anna Louise Keating (2013)](https://www.press.uillinois.edu/books/?id=p079399) remarks, as soon as a dichotomous framework defines reality "the collaborative negotiation and building of new or other opinions and truths" (6) becomes impossible. What might be needed to mitigate these risks at least partially, is that scholars, through rewriting, engage in a more fundamental, self-critical reconsideration of the dominant research cultures, including an awareness of their own involvement with them. This self-reflexivity might imply taking the responsibility and the risk of deviating from conventional knowledges, ways of knowing, or from what is considered and appraised as an academically valid output. Furthermore, it involves critically reflecting on the new potential closures enacted through (experimental) publishing undertakings.

### Further Readings
 
Ferreira da Silva, Denise. 2014. Toward a Black Feminist Poethics. *The Black Scholar*, 44(2): 81–97. [https://doi.org/10.1080/00064246.2014.11413690](https://doi.org/10.1080/00064246.2014.11413690)

Retallack, J. (2004). *The Poethical Wager*. University of California Press.

Rich, A. (1972). When We Dead Awaken: Writing as Re-Vision. *College English*, 34(1), 18. [https://doi.org/10.2307/375215](https://doi.org/10.2307/375215)

Rivera Garza, C. (2013). *Los muertos indóciles. Necroescrituras y desapropiación*. Tusquets Editores.

Rivera Garza, C. (2020). *The Restless Dead. Necrowriting and Disappropriation*. Vanderbilt University Press.